# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _medinterp
else:
    import _medinterp

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator_medinterp_module(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _medinterp.delete_SwigPyIterator_medinterp_module

    def value(self):
        return _medinterp.SwigPyIterator_medinterp_module_value(self)

    def incr(self, n=1):
        return _medinterp.SwigPyIterator_medinterp_module_incr(self, n)

    def decr(self, n=1):
        return _medinterp.SwigPyIterator_medinterp_module_decr(self, n)

    def distance(self, x):
        return _medinterp.SwigPyIterator_medinterp_module_distance(self, x)

    def equal(self, x):
        return _medinterp.SwigPyIterator_medinterp_module_equal(self, x)

    def copy(self):
        return _medinterp.SwigPyIterator_medinterp_module_copy(self)

    def next(self):
        return _medinterp.SwigPyIterator_medinterp_module_next(self)

    def __next__(self):
        return _medinterp.SwigPyIterator_medinterp_module___next__(self)

    def previous(self):
        return _medinterp.SwigPyIterator_medinterp_module_previous(self)

    def advance(self, n):
        return _medinterp.SwigPyIterator_medinterp_module_advance(self, n)

    def __eq__(self, x):
        return _medinterp.SwigPyIterator_medinterp_module___eq__(self, x)

    def __ne__(self, x):
        return _medinterp.SwigPyIterator_medinterp_module___ne__(self, x)

    def __iadd__(self, n):
        return _medinterp.SwigPyIterator_medinterp_module___iadd__(self, n)

    def __isub__(self, n):
        return _medinterp.SwigPyIterator_medinterp_module___isub__(self, n)

    def __add__(self, n):
        return _medinterp.SwigPyIterator_medinterp_module___add__(self, n)

    def __sub__(self, *args):
        return _medinterp.SwigPyIterator_medinterp_module___sub__(self, *args)
    def __iter__(self): return self
    def __iter__(self):
        return self

# Register SwigPyIterator_medinterp_module in _medinterp:
_medinterp.SwigPyIterator_medinterp_module_swigregister(SwigPyIterator_medinterp_module)

HAVE_CC_C99 = _medinterp.HAVE_CC_C99
HAVE_CUSERID = _medinterp.HAVE_CUSERID
HAVE_DLFCN_H = _medinterp.HAVE_DLFCN_H
HAVE_FTIME = _medinterp.HAVE_FTIME
HAVE_GETEUID = _medinterp.HAVE_GETEUID
HAVE_GETPWUID = _medinterp.HAVE_GETPWUID
HAVE_GETTIMEOFDAY = _medinterp.HAVE_GETTIMEOFDAY
HAVE_H5PUBLIC_H = _medinterp.HAVE_H5PUBLIC_H
HAVE_INT64 = _medinterp.HAVE_INT64
HAVE_INTTYPES_H = _medinterp.HAVE_INTTYPES_H
HAVE_MALLOC_H = _medinterp.HAVE_MALLOC_H
HAVE_MEMORY_H = _medinterp.HAVE_MEMORY_H
HAVE_PWD_H = _medinterp.HAVE_PWD_H
HAVE_STDBOOL_H = _medinterp.HAVE_STDBOOL_H
HAVE_STDINT_H = _medinterp.HAVE_STDINT_H
HAVE_STDLIB_H = _medinterp.HAVE_STDLIB_H
HAVE_STRINGS_H = _medinterp.HAVE_STRINGS_H
HAVE_STRING_H = _medinterp.HAVE_STRING_H
HAVE_SYS_STAT_H = _medinterp.HAVE_SYS_STAT_H
HAVE_SYS_TIMEB_H = _medinterp.HAVE_SYS_TIMEB_H
HAVE_SYS_TIME_H = _medinterp.HAVE_SYS_TIME_H
HAVE_SYS_TYPES_H = _medinterp.HAVE_SYS_TYPES_H
HAVE_UNISTD_H = _medinterp.HAVE_UNISTD_H
HAVE__BOOL = _medinterp.HAVE__BOOL
MED_CHECK_23FORMAT = _medinterp.MED_CHECK_23FORMAT
MED_HAVE_FORTRAN = _medinterp.MED_HAVE_FORTRAN
MESGERR = _medinterp.MESGERR
PACKAGE = _medinterp.PACKAGE
PACKAGE_BUGREPORT = _medinterp.PACKAGE_BUGREPORT
PACKAGE_NAME = _medinterp.PACKAGE_NAME
PACKAGE_STRING = _medinterp.PACKAGE_STRING
PACKAGE_URL = _medinterp.PACKAGE_URL
PACKAGE_VERSION = _medinterp.PACKAGE_VERSION
SIZEOF_FORTRAN_INTEGER = _medinterp.SIZEOF_FORTRAN_INTEGER
SIZEOF_INT = _medinterp.SIZEOF_INT
SIZEOF_LONG = _medinterp.SIZEOF_LONG
STDC_HEADERS = _medinterp.STDC_HEADERS
TIME_WITH_SYS_TIME = _medinterp.TIME_WITH_SYS_TIME
VERSION = _medinterp.VERSION
HDF_VERSION_REF = _medinterp.HDF_VERSION_REF
HDF_VERSION_MAJOR_REF = _medinterp.HDF_VERSION_MAJOR_REF
HDF_VERSION_MINOR_REF = _medinterp.HDF_VERSION_MINOR_REF
HDF_VERSION_RELEASE_REF = _medinterp.HDF_VERSION_RELEASE_REF
HDF_VERSION_NUM_REF = _medinterp.HDF_VERSION_NUM_REF
H5F_LIBVER_18 = _medinterp.H5F_LIBVER_18
MED_MAJOR_NUM = _medinterp.MED_MAJOR_NUM
MED_MINOR_NUM = _medinterp.MED_MINOR_NUM
MED_RELEASE_NUM = _medinterp.MED_RELEASE_NUM
MED_3_LATEST_MINOR = _medinterp.MED_3_LATEST_MINOR
MED_4_LATEST_MINOR = _medinterp.MED_4_LATEST_MINOR
MED_40_LATEST_RELEASE = _medinterp.MED_40_LATEST_RELEASE
MED_NUM_MAJEUR = _medinterp.MED_NUM_MAJEUR
MED_NUM_MINEUR = _medinterp.MED_NUM_MINEUR
MED_NUM_RELEASE = _medinterp.MED_NUM_RELEASE
MED_VERSION_STR = _medinterp.MED_VERSION_STR
MED_MAX_PARA = _medinterp.MED_MAX_PARA
MED_COMMENT_SIZE = _medinterp.MED_COMMENT_SIZE
MED_IDENT_SIZE = _medinterp.MED_IDENT_SIZE
MED_NAME_SIZE = _medinterp.MED_NAME_SIZE
MED_SNAME_SIZE = _medinterp.MED_SNAME_SIZE
MED_LNAME_SIZE = _medinterp.MED_LNAME_SIZE
MED_SNAME_BLANK = _medinterp.MED_SNAME_BLANK
MED_NAME_BLANK = _medinterp.MED_NAME_BLANK
MED_PATHNAME_SIZE = _medinterp.MED_PATHNAME_SIZE
MED_MAX_CHFID_PATH = _medinterp.MED_MAX_CHFID_PATH
MED_FULL_INTERLACE = _medinterp.MED_FULL_INTERLACE
MED_NO_INTERLACE = _medinterp.MED_NO_INTERLACE
MED_UNDEF_INTERLACE = _medinterp.MED_UNDEF_INTERLACE
MED_UNDEF_STMODE = _medinterp.MED_UNDEF_STMODE
MED_GLOBAL_STMODE = _medinterp.MED_GLOBAL_STMODE
MED_COMPACT_STMODE = _medinterp.MED_COMPACT_STMODE
MED_GLOBAL_PFLMODE = _medinterp.MED_GLOBAL_PFLMODE
MED_COMPACT_PFLMODE = _medinterp.MED_COMPACT_PFLMODE
MED_UNDEF_PFLMODE = _medinterp.MED_UNDEF_PFLMODE
MED_ACC_RDONLY = _medinterp.MED_ACC_RDONLY
MED_ACC_RDWR = _medinterp.MED_ACC_RDWR
MED_ACC_RDEXT = _medinterp.MED_ACC_RDEXT
MED_ACC_CREAT = _medinterp.MED_ACC_CREAT
MED_ACC_UNDEF = _medinterp.MED_ACC_UNDEF
MED_UNSTRUCTURED_MESH = _medinterp.MED_UNSTRUCTURED_MESH
MED_STRUCTURED_MESH = _medinterp.MED_STRUCTURED_MESH
MED_UNDEF_MESH_TYPE = _medinterp.MED_UNDEF_MESH_TYPE
MED_CARTESIAN_GRID = _medinterp.MED_CARTESIAN_GRID
MED_POLAR_GRID = _medinterp.MED_POLAR_GRID
MED_CURVILINEAR_GRID = _medinterp.MED_CURVILINEAR_GRID
MED_UNDEF_GRID_TYPE = _medinterp.MED_UNDEF_GRID_TYPE
MED_CELL = _medinterp.MED_CELL
MED_DESCENDING_FACE = _medinterp.MED_DESCENDING_FACE
MED_DESCENDING_EDGE = _medinterp.MED_DESCENDING_EDGE
MED_NODE = _medinterp.MED_NODE
MED_NODE_ELEMENT = _medinterp.MED_NODE_ELEMENT
MED_STRUCT_ELEMENT = _medinterp.MED_STRUCT_ELEMENT
MED_ALL_ENTITY_TYPE = _medinterp.MED_ALL_ENTITY_TYPE
MED_UNDEF_ENTITY_TYPE = _medinterp.MED_UNDEF_ENTITY_TYPE
MED_N_ENTITY_TYPES = _medinterp.MED_N_ENTITY_TYPES
MED_COORDINATE = _medinterp.MED_COORDINATE
MED_CONNECTIVITY = _medinterp.MED_CONNECTIVITY
MED_NAME = _medinterp.MED_NAME
MED_NUMBER = _medinterp.MED_NUMBER
MED_FAMILY_NUMBER = _medinterp.MED_FAMILY_NUMBER
MED_COORDINATE_AXIS1 = _medinterp.MED_COORDINATE_AXIS1
MED_COORDINATE_AXIS2 = _medinterp.MED_COORDINATE_AXIS2
MED_COORDINATE_AXIS3 = _medinterp.MED_COORDINATE_AXIS3
MED_INDEX_FACE = _medinterp.MED_INDEX_FACE
MED_INDEX_NODE = _medinterp.MED_INDEX_NODE
MED_GLOBAL_NUMBER = _medinterp.MED_GLOBAL_NUMBER
MED_VARIABLE_ATTRIBUTE = _medinterp.MED_VARIABLE_ATTRIBUTE
MED_COORDINATE_TRSF = _medinterp.MED_COORDINATE_TRSF
MED_UNDEF_DATATYPE = _medinterp.MED_UNDEF_DATATYPE
MED_INTERNAL_FLOAT32 = _medinterp.MED_INTERNAL_FLOAT32
MED_INTERNAL_FLOAT64 = _medinterp.MED_INTERNAL_FLOAT64
MED_INTERNAL_INT8 = _medinterp.MED_INTERNAL_INT8
MED_INTERNAL_INT32 = _medinterp.MED_INTERNAL_INT32
MED_INTERNAL_INT64 = _medinterp.MED_INTERNAL_INT64
MED_INTERNAL_INT = _medinterp.MED_INTERNAL_INT
MED_INTERNAL_NAME = _medinterp.MED_INTERNAL_NAME
MED_INTERNAL_SNAME = _medinterp.MED_INTERNAL_SNAME
MED_INTERNAL_LNAME = _medinterp.MED_INTERNAL_LNAME
MED_INTERNAL_IDENT = _medinterp.MED_INTERNAL_IDENT
MED_INTERNAL_CHAR = _medinterp.MED_INTERNAL_CHAR
MED_INTERNAL_UNDEF = _medinterp.MED_INTERNAL_UNDEF
MED_DOUBLE = _medinterp.MED_DOUBLE
MED_FLOAT64 = _medinterp.MED_FLOAT64
MED_FLOAT32 = _medinterp.MED_FLOAT32
MED_INT32 = _medinterp.MED_INT32
MED_INT64 = _medinterp.MED_INT64
MED_INT = _medinterp.MED_INT
MED_ATT_FLOAT64 = _medinterp.MED_ATT_FLOAT64
MED_ATT_INT = _medinterp.MED_ATT_INT
MED_ATT_NAME = _medinterp.MED_ATT_NAME
MED_ATT_UNDEF = _medinterp.MED_ATT_UNDEF
MED_MESH = _medinterp.MED_MESH
MED_FIELD = _medinterp.MED_FIELD
MED_LIBRARY = _medinterp.MED_LIBRARY
MED_FILE = _medinterp.MED_FILE
MED_MESH_SUPPORT = _medinterp.MED_MESH_SUPPORT
MED_ELSTRUCT = _medinterp.MED_ELSTRUCT
MED_FAMILY = _medinterp.MED_FAMILY
MED_EQUIVALENCE = _medinterp.MED_EQUIVALENCE
MED_GROUP = _medinterp.MED_GROUP
MED_JOINT = _medinterp.MED_JOINT
MED_LOCALIZATION = _medinterp.MED_LOCALIZATION
MED_PROFILE = _medinterp.MED_PROFILE
MED_FILTER = _medinterp.MED_FILTER
MED_INTERPOLATION = _medinterp.MED_INTERPOLATION
MED_NUMERICAL_DATA = _medinterp.MED_NUMERICAL_DATA
MED_LINK = _medinterp.MED_LINK
MED_CLASS_UNDEF = _medinterp.MED_CLASS_UNDEF
MED_CLASS_ALL = _medinterp.MED_CLASS_ALL
MED_POINT1 = _medinterp.MED_POINT1
MED_SEG2 = _medinterp.MED_SEG2
MED_SEG3 = _medinterp.MED_SEG3
MED_SEG4 = _medinterp.MED_SEG4
MED_TRIA3 = _medinterp.MED_TRIA3
MED_QUAD4 = _medinterp.MED_QUAD4
MED_TRIA6 = _medinterp.MED_TRIA6
MED_TRIA7 = _medinterp.MED_TRIA7
MED_QUAD8 = _medinterp.MED_QUAD8
MED_QUAD9 = _medinterp.MED_QUAD9
MED_TETRA4 = _medinterp.MED_TETRA4
MED_PYRA5 = _medinterp.MED_PYRA5
MED_PENTA6 = _medinterp.MED_PENTA6
MED_HEXA8 = _medinterp.MED_HEXA8
MED_TETRA10 = _medinterp.MED_TETRA10
MED_OCTA12 = _medinterp.MED_OCTA12
MED_PYRA13 = _medinterp.MED_PYRA13
MED_PENTA15 = _medinterp.MED_PENTA15
MED_PENTA18 = _medinterp.MED_PENTA18
MED_HEXA20 = _medinterp.MED_HEXA20
MED_HEXA27 = _medinterp.MED_HEXA27
MED_POLYGON = _medinterp.MED_POLYGON
MED_POLYGON2 = _medinterp.MED_POLYGON2
MED_POLYHEDRON = _medinterp.MED_POLYHEDRON
MED_STRUCT_GEO_INTERNAL = _medinterp.MED_STRUCT_GEO_INTERNAL
MED_STRUCT_GEO_SUP_INTERNAL = _medinterp.MED_STRUCT_GEO_SUP_INTERNAL
MED_NONE = _medinterp.MED_NONE
MED_NO_GEOTYPE = _medinterp.MED_NO_GEOTYPE
MED_UNDEF_GEOTYPE = _medinterp.MED_UNDEF_GEOTYPE
MED_UNDEF_GEOMETRY_TYPE = _medinterp.MED_UNDEF_GEOMETRY_TYPE
MED_ALL_GEOTYPE = _medinterp.MED_ALL_GEOTYPE
MED_GEO_ALL = _medinterp.MED_GEO_ALL
MED_N_CELL_GEO = _medinterp.MED_N_CELL_GEO
MED_N_CELL_FIXED_GEO = _medinterp.MED_N_CELL_FIXED_GEO
MED_N_CELL_GEO_FIXED_CON = _medinterp.MED_N_CELL_GEO_FIXED_CON
MED_N_FACE_GEO = _medinterp.MED_N_FACE_GEO
MED_N_FACE_FIXED_GEO = _medinterp.MED_N_FACE_FIXED_GEO
MED_N_FACE_GEO_FIXED_CON = _medinterp.MED_N_FACE_GEO_FIXED_CON
MED_N_EDGE_TYPES = _medinterp.MED_N_EDGE_TYPES
MED_N_EDGE_FIXED_GEO = _medinterp.MED_N_EDGE_FIXED_GEO
MED_N_EDGE_GEO_FIXED_CON = _medinterp.MED_N_EDGE_GEO_FIXED_CON
MED_N_NODE_GEO = _medinterp.MED_N_NODE_GEO
MED_N_NODE_FIXED_GEO = _medinterp.MED_N_NODE_FIXED_GEO
MED_N_NODE_GEO_FIXED_CON = _medinterp.MED_N_NODE_GEO_FIXED_CON
MED_NODAL = _medinterp.MED_NODAL
MED_DESCENDING = _medinterp.MED_DESCENDING
MED_UNDEF_CONNECTIVITY_MODE = _medinterp.MED_UNDEF_CONNECTIVITY_MODE
MED_NO_CMODE = _medinterp.MED_NO_CMODE
MED_CARTESIAN = _medinterp.MED_CARTESIAN
MED_CYLINDRICAL = _medinterp.MED_CYLINDRICAL
MED_SPHERICAL = _medinterp.MED_SPHERICAL
MED_UNDEF_AXIS_TYPE = _medinterp.MED_UNDEF_AXIS_TYPE
MED_FALSE = _medinterp.MED_FALSE
MED_TRUE = _medinterp.MED_TRUE
MED_GAUSS_ELNO = _medinterp.MED_GAUSS_ELNO
MED_IPOINT_ELNO = _medinterp.MED_IPOINT_ELNO
MED_NO_NAME = _medinterp.MED_NO_NAME
MED_NO_MESHNAME = _medinterp.MED_NO_MESHNAME
MED_NO_MESH = _medinterp.MED_NO_MESH
MED_NO_MESH_SUPPORT = _medinterp.MED_NO_MESH_SUPPORT
MED_NO_LOCALIZATION = _medinterp.MED_NO_LOCALIZATION
MED_NO_INTERPOLATION = _medinterp.MED_NO_INTERPOLATION
MED_NO_IPOINT_INTERNAL = _medinterp.MED_NO_IPOINT_INTERNAL
MED_NO_PROFILE = _medinterp.MED_NO_PROFILE
MED_NO_GROUP = _medinterp.MED_NO_GROUP
MED_ALLENTITIES_PROFILE = _medinterp.MED_ALLENTITIES_PROFILE
MED_NO_PROFILE_INTERNAL = _medinterp.MED_NO_PROFILE_INTERNAL
MED_SAME_PROFILE_INTERNAL = _medinterp.MED_SAME_PROFILE_INTERNAL
MED_ALL_CONSTITUENT = _medinterp.MED_ALL_CONSTITUENT
MED_UNDEF_SIZE = _medinterp.MED_UNDEF_SIZE
MED_NO_PROFILE_SIZE = _medinterp.MED_NO_PROFILE_SIZE
MED_SORT_DTIT = _medinterp.MED_SORT_DTIT
MED_SORT_ITDT = _medinterp.MED_SORT_ITDT
MED_SORT_UNDEF = _medinterp.MED_SORT_UNDEF
MED_ALL_DT = _medinterp.MED_ALL_DT
MED_ALL_IT = _medinterp.MED_ALL_IT
MED_NO_DT = _medinterp.MED_NO_DT
MED_NO_IT = _medinterp.MED_NO_IT
MED_UNDEF_DT = _medinterp.MED_UNDEF_DT
MED_ATT_NOT_FILLED = _medinterp.MED_ATT_NOT_FILLED
MED_MAX_FILTER_SPACES = _medinterp.MED_MAX_FILTER_SPACES
class med_filter(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    nspaces = property(_medinterp.med_filter_nspaces_get, _medinterp.med_filter_nspaces_set)
    memspace = property(_medinterp.med_filter_memspace_get, _medinterp.med_filter_memspace_set)
    diskspace = property(_medinterp.med_filter_diskspace_get, _medinterp.med_filter_diskspace_set)
    nentity = property(_medinterp.med_filter_nentity_get, _medinterp.med_filter_nentity_set)
    nvaluesperentity = property(_medinterp.med_filter_nvaluesperentity_get, _medinterp.med_filter_nvaluesperentity_set)
    nconstituentpervalue = property(_medinterp.med_filter_nconstituentpervalue_get, _medinterp.med_filter_nconstituentpervalue_set)
    constituentselect = property(_medinterp.med_filter_constituentselect_get, _medinterp.med_filter_constituentselect_set)
    switchmode = property(_medinterp.med_filter_switchmode_get, _medinterp.med_filter_switchmode_set)
    filterarraysize = property(_medinterp.med_filter_filterarraysize_get, _medinterp.med_filter_filterarraysize_set)
    filterarray23v30 = property(_medinterp.med_filter_filterarray23v30_get, _medinterp.med_filter_filterarray23v30_set)
    profilearraysize = property(_medinterp.med_filter_profilearraysize_get, _medinterp.med_filter_profilearraysize_set)
    storagemode = property(_medinterp.med_filter_storagemode_get, _medinterp.med_filter_storagemode_set)
    profilename = property(_medinterp.med_filter_profilename_get, _medinterp.med_filter_profilename_set)

    def __init__(self):
        r"""__init__(self) -> med_filter"""
        _medinterp.med_filter_swiginit(self, _medinterp.new_med_filter())
    __swig_destroy__ = _medinterp.delete_med_filter

# Register med_filter in _medinterp:
_medinterp.med_filter_swigregister(med_filter)

MED_NO_FILTER_SIZE = _medinterp.MED_NO_FILTER_SIZE
MED_NO_PROFILE_F = _medinterp.MED_NO_PROFILE_F
class med_file_version(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    majeur = property(_medinterp.med_file_version_majeur_get, _medinterp.med_file_version_majeur_set)
    mineur = property(_medinterp.med_file_version_mineur_get, _medinterp.med_file_version_mineur_set)
    release = property(_medinterp.med_file_version_release_get, _medinterp.med_file_version_release_set)

    def __init__(self):
        r"""__init__(self) -> med_file_version"""
        _medinterp.med_file_version_swiginit(self, _medinterp.new_med_file_version())
    __swig_destroy__ = _medinterp.delete_med_file_version

# Register med_file_version in _medinterp:
_medinterp.med_file_version_swigregister(med_file_version)

class med_memfile(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    app_image_ptr = property(_medinterp.med_memfile_app_image_ptr_get, _medinterp.med_memfile_app_image_ptr_set)
    app_image_size = property(_medinterp.med_memfile_app_image_size_get, _medinterp.med_memfile_app_image_size_set)
    ref_count = property(_medinterp.med_memfile_ref_count_get, _medinterp.med_memfile_ref_count_set)
    fapl_image_ptr = property(_medinterp.med_memfile_fapl_image_ptr_get, _medinterp.med_memfile_fapl_image_ptr_set)
    fapl_image_size = property(_medinterp.med_memfile_fapl_image_size_get, _medinterp.med_memfile_fapl_image_size_set)
    fapl_ref_count = property(_medinterp.med_memfile_fapl_ref_count_get, _medinterp.med_memfile_fapl_ref_count_set)
    vfd_image_ptr = property(_medinterp.med_memfile_vfd_image_ptr_get, _medinterp.med_memfile_vfd_image_ptr_set)
    vfd_image_size = property(_medinterp.med_memfile_vfd_image_size_get, _medinterp.med_memfile_vfd_image_size_set)
    vfd_ref_count = property(_medinterp.med_memfile_vfd_ref_count_get, _medinterp.med_memfile_vfd_ref_count_set)
    flags = property(_medinterp.med_memfile_flags_get, _medinterp.med_memfile_flags_set)

    def __init__(self):
        r"""__init__(self) -> med_memfile"""
        _medinterp.med_memfile_swiginit(self, _medinterp.new_med_memfile())
    __swig_destroy__ = _medinterp.delete_med_memfile

# Register med_memfile in _medinterp:
_medinterp.med_memfile_swigregister(med_memfile)


def MEDgetEntityTypeIt(entitytype):
    return _medinterp.MEDgetEntityTypeIt(entitytype)

def MEDgetCellGeometryTypeIt(geotype):
    return _medinterp.MEDgetCellGeometryTypeIt(geotype)

def MEDgetFaceGeometryTypeIt(geotype):
    return _medinterp.MEDgetFaceGeometryTypeIt(geotype)

def MEDgetEdgeGeometryTypeIt(geotype):
    return _medinterp.MEDgetEdgeGeometryTypeIt(geotype)

def MEDgetNodeGeometryTypeIt(geotype):
    return _medinterp.MEDgetNodeGeometryTypeIt(geotype)

def MEDgetEntityGeometryTypeIt(entitytype, geotype):
    return _medinterp.MEDgetEntityGeometryTypeIt(entitytype, geotype)

def MEDgetGeometryTypeName(geotype):
    return _medinterp.MEDgetGeometryTypeName(geotype)

def MEDgetEntityTypeName(entitytype):
    return _medinterp.MEDgetEntityTypeName(entitytype)
MED_PARTICLE_NAME = _medinterp.MED_PARTICLE_NAME
MED_BALL_NAME = _medinterp.MED_BALL_NAME
MED_BEAM_NAME = _medinterp.MED_BEAM_NAME
MED_PARTICLE_LABEL = _medinterp.MED_PARTICLE_LABEL
MED_BALL_DIAMETER = _medinterp.MED_BALL_DIAMETER
MED_BEAM_THICKNESS = _medinterp.MED_BEAM_THICKNESS
import med.medenum
class MEDBOOL(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medinterp.MEDBOOL_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medinterp.MEDBOOL___nonzero__(self)

    def __bool__(self):
        return _medinterp.MEDBOOL___bool__(self)

    def __len__(self):
        return _medinterp.MEDBOOL___len__(self)

    def __getslice__(self, i, j):
        return _medinterp.MEDBOOL___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medinterp.MEDBOOL___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medinterp.MEDBOOL___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medinterp.MEDBOOL___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medinterp.MEDBOOL___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medinterp.MEDBOOL___setitem__(self, *args)

    def pop(self):
        return _medinterp.MEDBOOL_pop(self)

    def append(self, x):
        return _medinterp.MEDBOOL_append(self, x)

    def empty(self):
        return _medinterp.MEDBOOL_empty(self)

    def size(self):
        return _medinterp.MEDBOOL_size(self)

    def swap(self, v):
        return _medinterp.MEDBOOL_swap(self, v)

    def begin(self):
        return _medinterp.MEDBOOL_begin(self)

    def end(self):
        return _medinterp.MEDBOOL_end(self)

    def rbegin(self):
        return _medinterp.MEDBOOL_rbegin(self)

    def rend(self):
        return _medinterp.MEDBOOL_rend(self)

    def clear(self):
        return _medinterp.MEDBOOL_clear(self)

    def get_allocator(self):
        return _medinterp.MEDBOOL_get_allocator(self)

    def pop_back(self):
        return _medinterp.MEDBOOL_pop_back(self)

    def erase(self, *args):
        return _medinterp.MEDBOOL_erase(self, *args)

    def __init__(self, *args):
        _medinterp.MEDBOOL_swiginit(self, _medinterp.new_MEDBOOL(*args))

    def push_back(self, x):
        return _medinterp.MEDBOOL_push_back(self, x)

    def front(self):
        return _medinterp.MEDBOOL_front(self)

    def back(self):
        return _medinterp.MEDBOOL_back(self)

    def assign(self, n, x):
        return _medinterp.MEDBOOL_assign(self, n, x)

    def resize(self, *args):
        return _medinterp.MEDBOOL_resize(self, *args)

    def insert(self, *args):
        return _medinterp.MEDBOOL_insert(self, *args)

    def reserve(self, n):
        return _medinterp.MEDBOOL_reserve(self, n)

    def capacity(self):
        return _medinterp.MEDBOOL_capacity(self)
    __swig_destroy__ = _medinterp.delete_MEDBOOL

# Register MEDBOOL in _medinterp:
_medinterp.MEDBOOL_swigregister(MEDBOOL)
cvar = _medinterp.cvar
MED_GET_ENTITY_TYPENAME = cvar.MED_GET_ENTITY_TYPENAME
MED_GET_CELL_GEOMETRY_TYPENAME = cvar.MED_GET_CELL_GEOMETRY_TYPENAME
MED_GET_FACE_GEOMETRY_TYPENAME = cvar.MED_GET_FACE_GEOMETRY_TYPENAME
MED_GET_CELL_GEOMETRY_TYPE_FROM_ENTITY_TYPE = cvar.MED_GET_CELL_GEOMETRY_TYPE_FROM_ENTITY_TYPE
MED_GET_N_FIXED_GEO_FOR_ENTITY_TYPE_IT = cvar.MED_GET_N_FIXED_GEO_FOR_ENTITY_TYPE_IT


MEDBOOL.__str__= lambda self: str([x for x in self])
MEDBOOL.__repr__= lambda self: "MEDBOOL("+str([x for x in self])+")"

class MEDFLOAT(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medinterp.MEDFLOAT_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medinterp.MEDFLOAT___nonzero__(self)

    def __bool__(self):
        return _medinterp.MEDFLOAT___bool__(self)

    def __len__(self):
        return _medinterp.MEDFLOAT___len__(self)

    def __getslice__(self, i, j):
        return _medinterp.MEDFLOAT___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medinterp.MEDFLOAT___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medinterp.MEDFLOAT___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medinterp.MEDFLOAT___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medinterp.MEDFLOAT___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medinterp.MEDFLOAT___setitem__(self, *args)

    def pop(self):
        return _medinterp.MEDFLOAT_pop(self)

    def append(self, x):
        return _medinterp.MEDFLOAT_append(self, x)

    def empty(self):
        return _medinterp.MEDFLOAT_empty(self)

    def size(self):
        return _medinterp.MEDFLOAT_size(self)

    def swap(self, v):
        return _medinterp.MEDFLOAT_swap(self, v)

    def begin(self):
        return _medinterp.MEDFLOAT_begin(self)

    def end(self):
        return _medinterp.MEDFLOAT_end(self)

    def rbegin(self):
        return _medinterp.MEDFLOAT_rbegin(self)

    def rend(self):
        return _medinterp.MEDFLOAT_rend(self)

    def clear(self):
        return _medinterp.MEDFLOAT_clear(self)

    def get_allocator(self):
        return _medinterp.MEDFLOAT_get_allocator(self)

    def pop_back(self):
        return _medinterp.MEDFLOAT_pop_back(self)

    def erase(self, *args):
        return _medinterp.MEDFLOAT_erase(self, *args)

    def __init__(self, *args):
        _medinterp.MEDFLOAT_swiginit(self, _medinterp.new_MEDFLOAT(*args))

    def push_back(self, x):
        return _medinterp.MEDFLOAT_push_back(self, x)

    def front(self):
        return _medinterp.MEDFLOAT_front(self)

    def back(self):
        return _medinterp.MEDFLOAT_back(self)

    def assign(self, n, x):
        return _medinterp.MEDFLOAT_assign(self, n, x)

    def resize(self, *args):
        return _medinterp.MEDFLOAT_resize(self, *args)

    def insert(self, *args):
        return _medinterp.MEDFLOAT_insert(self, *args)

    def reserve(self, n):
        return _medinterp.MEDFLOAT_reserve(self, n)

    def capacity(self):
        return _medinterp.MEDFLOAT_capacity(self)

    def __iadd__(self, value):
        return _medinterp.MEDFLOAT___iadd__(self, value)

    def __add__(self, value):
        return _medinterp.MEDFLOAT___add__(self, value)

    def __isub__(self, value):
        return _medinterp.MEDFLOAT___isub__(self, value)

    def __sub__(self, value):
        return _medinterp.MEDFLOAT___sub__(self, value)

    def __imul__(self, value):
        return _medinterp.MEDFLOAT___imul__(self, value)

    def __mul__(self, value):
        return _medinterp.MEDFLOAT___mul__(self, value)

    def __itruediv__(self, *args):
        return _medinterp.MEDFLOAT___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medinterp.MEDFLOAT___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medinterp.MEDFLOAT___le__(self, value)

    def __lt__(self, value):
        return _medinterp.MEDFLOAT___lt__(self, value)

    def __gt__(self, value):
        return _medinterp.MEDFLOAT___gt__(self, value)

    def __ge__(self, value):
        return _medinterp.MEDFLOAT___ge__(self, value)

    def __eq__(self, value):
        return _medinterp.MEDFLOAT___eq__(self, value)

    def __ne__(self, value):
        return _medinterp.MEDFLOAT___ne__(self, value)
    __swig_destroy__ = _medinterp.delete_MEDFLOAT

# Register MEDFLOAT in _medinterp:
_medinterp.MEDFLOAT_swigregister(MEDFLOAT)


MEDFLOAT.__str__= lambda self: str([x for x in self])
MEDFLOAT.__repr__= lambda self:"MEDFLOAT" +"("+str([x for x in self])+")"


MEDFLOAT64=MEDFLOAT
MEDDOUBLE=MEDFLOAT

class MEDFLOAT32(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medinterp.MEDFLOAT32_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medinterp.MEDFLOAT32___nonzero__(self)

    def __bool__(self):
        return _medinterp.MEDFLOAT32___bool__(self)

    def __len__(self):
        return _medinterp.MEDFLOAT32___len__(self)

    def __getslice__(self, i, j):
        return _medinterp.MEDFLOAT32___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medinterp.MEDFLOAT32___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medinterp.MEDFLOAT32___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medinterp.MEDFLOAT32___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medinterp.MEDFLOAT32___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medinterp.MEDFLOAT32___setitem__(self, *args)

    def pop(self):
        return _medinterp.MEDFLOAT32_pop(self)

    def append(self, x):
        return _medinterp.MEDFLOAT32_append(self, x)

    def empty(self):
        return _medinterp.MEDFLOAT32_empty(self)

    def size(self):
        return _medinterp.MEDFLOAT32_size(self)

    def swap(self, v):
        return _medinterp.MEDFLOAT32_swap(self, v)

    def begin(self):
        return _medinterp.MEDFLOAT32_begin(self)

    def end(self):
        return _medinterp.MEDFLOAT32_end(self)

    def rbegin(self):
        return _medinterp.MEDFLOAT32_rbegin(self)

    def rend(self):
        return _medinterp.MEDFLOAT32_rend(self)

    def clear(self):
        return _medinterp.MEDFLOAT32_clear(self)

    def get_allocator(self):
        return _medinterp.MEDFLOAT32_get_allocator(self)

    def pop_back(self):
        return _medinterp.MEDFLOAT32_pop_back(self)

    def erase(self, *args):
        return _medinterp.MEDFLOAT32_erase(self, *args)

    def __init__(self, *args):
        _medinterp.MEDFLOAT32_swiginit(self, _medinterp.new_MEDFLOAT32(*args))

    def push_back(self, x):
        return _medinterp.MEDFLOAT32_push_back(self, x)

    def front(self):
        return _medinterp.MEDFLOAT32_front(self)

    def back(self):
        return _medinterp.MEDFLOAT32_back(self)

    def assign(self, n, x):
        return _medinterp.MEDFLOAT32_assign(self, n, x)

    def resize(self, *args):
        return _medinterp.MEDFLOAT32_resize(self, *args)

    def insert(self, *args):
        return _medinterp.MEDFLOAT32_insert(self, *args)

    def reserve(self, n):
        return _medinterp.MEDFLOAT32_reserve(self, n)

    def capacity(self):
        return _medinterp.MEDFLOAT32_capacity(self)

    def __iadd__(self, value):
        return _medinterp.MEDFLOAT32___iadd__(self, value)

    def __add__(self, value):
        return _medinterp.MEDFLOAT32___add__(self, value)

    def __isub__(self, value):
        return _medinterp.MEDFLOAT32___isub__(self, value)

    def __sub__(self, value):
        return _medinterp.MEDFLOAT32___sub__(self, value)

    def __imul__(self, value):
        return _medinterp.MEDFLOAT32___imul__(self, value)

    def __mul__(self, value):
        return _medinterp.MEDFLOAT32___mul__(self, value)

    def __itruediv__(self, *args):
        return _medinterp.MEDFLOAT32___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medinterp.MEDFLOAT32___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medinterp.MEDFLOAT32___le__(self, value)

    def __lt__(self, value):
        return _medinterp.MEDFLOAT32___lt__(self, value)

    def __gt__(self, value):
        return _medinterp.MEDFLOAT32___gt__(self, value)

    def __ge__(self, value):
        return _medinterp.MEDFLOAT32___ge__(self, value)

    def __eq__(self, value):
        return _medinterp.MEDFLOAT32___eq__(self, value)

    def __ne__(self, value):
        return _medinterp.MEDFLOAT32___ne__(self, value)
    __swig_destroy__ = _medinterp.delete_MEDFLOAT32

# Register MEDFLOAT32 in _medinterp:
_medinterp.MEDFLOAT32_swigregister(MEDFLOAT32)


MEDFLOAT32.__str__= lambda self: str([x for x in self])
MEDFLOAT32.__repr__= lambda self:"MEDFLOAT32" +"("+str([x for x in self])+")"

class MEDINT(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medinterp.MEDINT_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medinterp.MEDINT___nonzero__(self)

    def __bool__(self):
        return _medinterp.MEDINT___bool__(self)

    def __len__(self):
        return _medinterp.MEDINT___len__(self)

    def __getslice__(self, i, j):
        return _medinterp.MEDINT___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medinterp.MEDINT___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medinterp.MEDINT___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medinterp.MEDINT___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medinterp.MEDINT___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medinterp.MEDINT___setitem__(self, *args)

    def pop(self):
        return _medinterp.MEDINT_pop(self)

    def append(self, x):
        return _medinterp.MEDINT_append(self, x)

    def empty(self):
        return _medinterp.MEDINT_empty(self)

    def size(self):
        return _medinterp.MEDINT_size(self)

    def swap(self, v):
        return _medinterp.MEDINT_swap(self, v)

    def begin(self):
        return _medinterp.MEDINT_begin(self)

    def end(self):
        return _medinterp.MEDINT_end(self)

    def rbegin(self):
        return _medinterp.MEDINT_rbegin(self)

    def rend(self):
        return _medinterp.MEDINT_rend(self)

    def clear(self):
        return _medinterp.MEDINT_clear(self)

    def get_allocator(self):
        return _medinterp.MEDINT_get_allocator(self)

    def pop_back(self):
        return _medinterp.MEDINT_pop_back(self)

    def erase(self, *args):
        return _medinterp.MEDINT_erase(self, *args)

    def __init__(self, *args):
        _medinterp.MEDINT_swiginit(self, _medinterp.new_MEDINT(*args))

    def push_back(self, x):
        return _medinterp.MEDINT_push_back(self, x)

    def front(self):
        return _medinterp.MEDINT_front(self)

    def back(self):
        return _medinterp.MEDINT_back(self)

    def assign(self, n, x):
        return _medinterp.MEDINT_assign(self, n, x)

    def resize(self, *args):
        return _medinterp.MEDINT_resize(self, *args)

    def insert(self, *args):
        return _medinterp.MEDINT_insert(self, *args)

    def reserve(self, n):
        return _medinterp.MEDINT_reserve(self, n)

    def capacity(self):
        return _medinterp.MEDINT_capacity(self)

    def __iadd__(self, value):
        return _medinterp.MEDINT___iadd__(self, value)

    def __add__(self, value):
        return _medinterp.MEDINT___add__(self, value)

    def __isub__(self, value):
        return _medinterp.MEDINT___isub__(self, value)

    def __sub__(self, value):
        return _medinterp.MEDINT___sub__(self, value)

    def __imul__(self, value):
        return _medinterp.MEDINT___imul__(self, value)

    def __mul__(self, value):
        return _medinterp.MEDINT___mul__(self, value)

    def __itruediv__(self, *args):
        return _medinterp.MEDINT___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medinterp.MEDINT___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medinterp.MEDINT___le__(self, value)

    def __lt__(self, value):
        return _medinterp.MEDINT___lt__(self, value)

    def __gt__(self, value):
        return _medinterp.MEDINT___gt__(self, value)

    def __ge__(self, value):
        return _medinterp.MEDINT___ge__(self, value)

    def __eq__(self, value):
        return _medinterp.MEDINT___eq__(self, value)

    def __ne__(self, value):
        return _medinterp.MEDINT___ne__(self, value)
    __swig_destroy__ = _medinterp.delete_MEDINT

# Register MEDINT in _medinterp:
_medinterp.MEDINT_swigregister(MEDINT)


MEDINT.__str__= lambda self: str([x for x in self])
MEDINT.__repr__= lambda self:"MEDINT" +"("+str([x for x in self])+")"


MEDINT32=MEDINT


MEDINT64=None

class MEDCHAR(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _medinterp.MEDCHAR_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _medinterp.MEDCHAR___nonzero__(self)

    def __bool__(self):
        return _medinterp.MEDCHAR___bool__(self)

    def __len__(self):
        return _medinterp.MEDCHAR___len__(self)

    def __getslice__(self, i, j):
        return _medinterp.MEDCHAR___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _medinterp.MEDCHAR___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _medinterp.MEDCHAR___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _medinterp.MEDCHAR___delitem__(self, *args)

    def __getitem__(self, *args):
        return _medinterp.MEDCHAR___getitem__(self, *args)

    def __setitem__(self, *args):
        return _medinterp.MEDCHAR___setitem__(self, *args)

    def pop(self):
        return _medinterp.MEDCHAR_pop(self)

    def append(self, x):
        return _medinterp.MEDCHAR_append(self, x)

    def empty(self):
        return _medinterp.MEDCHAR_empty(self)

    def size(self):
        return _medinterp.MEDCHAR_size(self)

    def swap(self, v):
        return _medinterp.MEDCHAR_swap(self, v)

    def begin(self):
        return _medinterp.MEDCHAR_begin(self)

    def end(self):
        return _medinterp.MEDCHAR_end(self)

    def rbegin(self):
        return _medinterp.MEDCHAR_rbegin(self)

    def rend(self):
        return _medinterp.MEDCHAR_rend(self)

    def clear(self):
        return _medinterp.MEDCHAR_clear(self)

    def get_allocator(self):
        return _medinterp.MEDCHAR_get_allocator(self)

    def pop_back(self):
        return _medinterp.MEDCHAR_pop_back(self)

    def erase(self, *args):
        return _medinterp.MEDCHAR_erase(self, *args)

    def __init__(self, *args):
        _medinterp.MEDCHAR_swiginit(self, _medinterp.new_MEDCHAR(*args))

    def push_back(self, x):
        return _medinterp.MEDCHAR_push_back(self, x)

    def front(self):
        return _medinterp.MEDCHAR_front(self)

    def back(self):
        return _medinterp.MEDCHAR_back(self)

    def assign(self, n, x):
        return _medinterp.MEDCHAR_assign(self, n, x)

    def resize(self, *args):
        return _medinterp.MEDCHAR_resize(self, *args)

    def insert(self, *args):
        return _medinterp.MEDCHAR_insert(self, *args)

    def reserve(self, n):
        return _medinterp.MEDCHAR_reserve(self, n)

    def capacity(self):
        return _medinterp.MEDCHAR_capacity(self)

    def __iadd__(self, value):
        return _medinterp.MEDCHAR___iadd__(self, value)

    def __add__(self, value):
        return _medinterp.MEDCHAR___add__(self, value)

    def __isub__(self, value):
        return _medinterp.MEDCHAR___isub__(self, value)

    def __sub__(self, value):
        return _medinterp.MEDCHAR___sub__(self, value)

    def __imul__(self, value):
        return _medinterp.MEDCHAR___imul__(self, value)

    def __mul__(self, value):
        return _medinterp.MEDCHAR___mul__(self, value)

    def __itruediv__(self, *args):
        return _medinterp.MEDCHAR___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medinterp.MEDCHAR___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value):
        return _medinterp.MEDCHAR___le__(self, value)

    def __lt__(self, value):
        return _medinterp.MEDCHAR___lt__(self, value)

    def __gt__(self, value):
        return _medinterp.MEDCHAR___gt__(self, value)

    def __ge__(self, value):
        return _medinterp.MEDCHAR___ge__(self, value)

    def __eq__(self, value):
        return _medinterp.MEDCHAR___eq__(self, value)

    def __ne__(self, value):
        return _medinterp.MEDCHAR___ne__(self, value)
    __swig_destroy__ = _medinterp.delete_MEDCHAR

# Register MEDCHAR in _medinterp:
_medinterp.MEDCHAR_swigregister(MEDCHAR)


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


def MEDinterpCr(fid, interpname, geotype, cellnodes, nvariable, maxdegree, nmaxcoef):
    r"""
    MEDinterpCr(fid, interpname, geotype, cellnodes, nvariable, maxdegree, nmaxcoef) -> med_err

    Parameters
    ----------
    fid: med_idt const
    interpname: char const *const
    geotype: med_geometry_type const
    cellnodes: enum med_bool const
    nvariable: med_int const
    maxdegree: med_int const
    nmaxcoef: med_int const

    """
    return _medinterp.MEDinterpCr(fid, interpname, geotype, cellnodes, nvariable, maxdegree, nmaxcoef)

def MEDinterpBaseFunctionWr(fid, interpname, basisfuncit, ncoef, power, coefficient):
    r"""
    MEDinterpBaseFunctionWr(fid, interpname, basisfuncit, ncoef, power, coefficient) -> med_err

    Parameters
    ----------
    fid: med_idt const
    interpname: char const *const
    basisfuncit: med_int const
    ncoef: med_int const
    power: med_int const *const
    coefficient: med_float const *const

    """
    return _medinterp.MEDinterpBaseFunctionWr(fid, interpname, basisfuncit, ncoef, power, coefficient)

def MEDnInterp(fid):
    r"""
    MEDnInterp(fid) -> med_int

    Parameters
    ----------
    fid: med_idt const

    """
    return _medinterp.MEDnInterp(fid)

def MEDinterpInfo(fid, interpit):
    r"""
    MEDinterpInfo(fid, interpit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    interpit: int const

    """
    return _medinterp.MEDinterpInfo(fid, interpit)

def MEDinterpInfoByName(fid, interpname):
    r"""
    MEDinterpInfoByName(fid, interpname) -> med_err

    Parameters
    ----------
    fid: med_idt const
    interpname: char const *const

    """
    return _medinterp.MEDinterpInfoByName(fid, interpname)

def MEDinterpBaseFunctionRd(fid, interpname, basisfuncit, power, coefficient):
    r"""
    MEDinterpBaseFunctionRd(fid, interpname, basisfuncit, power, coefficient) -> med_err

    Parameters
    ----------
    fid: med_idt const
    interpname: char const *const
    basisfuncit: int const
    power: med_int *const
    coefficient: med_float *const

    """
    return _medinterp.MEDinterpBaseFunctionRd(fid, interpname, basisfuncit, power, coefficient)

def MEDinterpBaseFunctionCoefSize(fid, interpname, basisfuncit):
    r"""
    MEDinterpBaseFunctionCoefSize(fid, interpname, basisfuncit) -> med_int

    Parameters
    ----------
    fid: med_idt const
    interpname: char const *const
    basisfuncit: med_int const

    """
    return _medinterp.MEDinterpBaseFunctionCoefSize(fid, interpname, basisfuncit)


